%undefine __cmake_in_source_build

Summary:        A collection of tools, libraries, and tests for Vulkan shader compilation
Name:           shaderc
Version:        2023.3
Release:        3%{?dist}
License:        Apache-2.0
URL:            https://github.com/google/shaderc
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz

Patch3001:      0001-Drop-third-party-code-in-CMakeLists.txt.patch
Patch3002:      glslang_linker_flags.patch

BuildRequires:  cmake gcc-c++ ninja-build python3-devel glslang-devel
BuildRequires:  spirv-headers-devel spirv-tools spirv-tools-devel

%description
A collection of tools, libraries and tests for shader compilation.

Shaderc aims to to provide:
 - a command line compiler with GCC- and Clang-like usage, for better integration with build systems
 - an API where functionality can be added without breaking existing clients
 - an API supporting standard concurrency patterns across multiple operating systems
 - increased functionality such as file #include support

%package    -n  glslc
Summary:        A command line compiler for GLSL/HLSL to SPIR-V

%description -n glslc
A command line compiler for GLSL/HLSL to SPIR-V.

%package    -n  libshaderc
Summary:        A library for compiling shader strings into SPIR-V

%description -n libshaderc
A library for compiling shader strings into SPIR-V.

%package -n     libshaderc-devel
Summary:        Development files for libshaderc
Requires:       libshaderc = %{version}-%{release}

%description -n libshaderc-devel
A library for compiling shader strings into SPIR-V.

Development files for libshaderc.

%package -n     libshaderc-static
Summary:        A library for compiling shader strings into SPIR-V (static libraries)

%description -n libshaderc-static
A library for compiling shader strings into SPIR-V.

Static libraries for libshaderc.

%prep
%autosetup -p1 -n %{name}-%{version}

rm -rf third_party

sed -i -e '/build-version/d' glslc/CMakeLists.txt
echo \"shaderc $(grep -m1 -o '^v[[:digit:]]\{4\}\.[[:digit:]]\(-dev\)\? [[:digit:]]\{4\}-[[:digit:]]\{2\}-[[:digit:]]\{2\}$' CHANGES)\" \
        > glslc/src/build-version.inc
echo \"spirv-tools $(grep -m1 -o '^v[[:digit:]]\{4\}\.[[:digit:]]\(-dev\)\? [[:digit:]]\{4\}-[[:digit:]]\{2\}-[[:digit:]]\{2\}$' /usr/share/doc/spirv-tools/CHANGES)\" \
        >> glslc/src/build-version.inc
echo \"glslang %{glslang_version}\" >> glslc/src/build-version.inc

sed -i 's|SPIRV/GlslangToSpv.h|glslang/SPIRV/GlslangToSpv.h|' libshaderc_util/src/compiler.cc

%build
%cmake  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCMAKE_SKIP_RPATH=True \
        -DSHADERC_SKIP_TESTS=True \
        -DPYTHON_EXE=%{__python3} \
        -GNinja
%cmake_build

%install
%cmake_install

%check
%ctest

%files -n glslc
%license LICENSE
%doc glslc/README.asciidoc
%{_bindir}/glslc

%files -n libshaderc
%license LICENSE
%doc AUTHORS CHANGES CONTRIBUTORS README.md
%{_libdir}/libshaderc_shared.so.1*

%files -n libshaderc-devel
%{_includedir}/%{name}/
%{_libdir}/libshaderc_shared.so
%{_libdir}/pkgconfig/shaderc.pc

%files -n libshaderc-static
%license LICENSE
%{_libdir}/libshaderc.a
%{_libdir}/libshaderc_combined.a
%{_libdir}/pkgconfig/shaderc_static.pc
%{_libdir}/pkgconfig/shaderc_combined.pc

%changelog
* Mon Dec 25 2023 luffyluo <luffyluo@tencent.com> - 2023.3-3
- Rebuilt for vulkan-loader 1.3.268.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2023.3-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 11 2023 Shuo Wang <abushwang@tencent.com> - 2023.3-1
- update to 2023.3

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.4-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2022.4-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Dec 5 2022 Shuo Wang <abushwang@tencent.com> - 2022.4-1
- initial build
